==> zio-aws-cloudfront_2.13-5.17.104.3-sources.jar: zio/aws/cloudfront/model/ListPublicKeysRequest.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListPublicKeysRequest(
    marker: Option[String] = None,
    maxItems: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest = {
    import ListPublicKeysRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(maxItems.map(value => value: java.lang.String))(
        _.maxItems
      )
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.ListPublicKeysRequest.ReadOnly =
    zio.aws.cloudfront.model.ListPublicKeysRequest.wrap(buildAwsValue())
}
object ListPublicKeysRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.ListPublicKeysRequest =
      zio.aws.cloudfront.model.ListPublicKeysRequest(
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def marker: Option[String]
    def maxItems: Option[String]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
  ) extends zio.aws.cloudfront.model.ListPublicKeysRequest.ReadOnly {
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val maxItems: Option[String] =
      scala.Option(impl.maxItems()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
  ): zio.aws.cloudfront.model.ListPublicKeysRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.183.1-sources.jar: zio/aws/cloudfront/model/ListPublicKeysRequest.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListPublicKeysRequest(
    marker: Optional[String] = Optional.Absent,
    maxItems: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest = {
    import ListPublicKeysRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(maxItems.map(value => value: java.lang.String))(
        _.maxItems
      )
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.ListPublicKeysRequest.ReadOnly =
    zio.aws.cloudfront.model.ListPublicKeysRequest.wrap(buildAwsValue())
}
object ListPublicKeysRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.ListPublicKeysRequest =
      zio.aws.cloudfront.model.ListPublicKeysRequest(
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def marker: Optional[String]
    def maxItems: Optional[String]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
  ) extends zio.aws.cloudfront.model.ListPublicKeysRequest.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val maxItems: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.maxItems())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ListPublicKeysRequest
  ): zio.aws.cloudfront.model.ListPublicKeysRequest.ReadOnly = new Wrapper(impl)
}
